Skip to contents

Get API key for OpenAlex API

Usage

opt_api_key(api_key)

Arguments

api_key

character vector or NULL. If specified, value to assign to the api key option. Default is `NULL`.

Value

The API key, if `api_key` is not specified the current one, otherwise the old one.