Calls openalex-snapshot with the given argument vector via
system2() and aborts with an informative error if the process exits
with a non-zero status code.
Usage
run_oas(args, oas_bin = NULL, error_call = rlang::caller_env())Calls openalex-snapshot with the given argument vector via
system2() and aborts with an informative error if the process exits
with a non-zero status code.
run_oas(args, oas_bin = NULL, error_call = rlang::caller_env())