R/opt_api_key.R
opt_api_key.Rd
Get API key for OpenAlex API
opt_api_key(api_key)
character vector or NULL. If specified, value to assign to the api key option. Default is `NULL`.
The API key, if `api_key` is not specified the current one, otherwise the old one.